# pep723

Implementation of [PEP 723](https://peps.python.org/pep-0723/#reference-implementation)

## Usage

```
$ pip install pep723
```

Run a script which has **inline script metadata**.

```
$ python -m pep723.tool example/script_with_metadata.py
```

## ⚠️Caution

This project is for self-education.  
DO NOT USE IN PRODUCTION.

If you are looking for tools which support PEP 723, recommendations are

* pipx
* uv
* Hatch
* PDM
